/*
 * Allgemeine Funktionen mit und ohne Datenverteilerbezug
 * Copyright (C) 2007-2015 BitCtrl Systems GmbH
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal;

import java.util.Arrays;
import java.util.Collection;

import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.sys.funclib.bitctrl.modell.ModellObjektFactory;
import de.bsvrz.sys.funclib.bitctrl.modell.SystemObjekt;
import de.bsvrz.sys.funclib.bitctrl.modell.SystemObjektTyp;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Aktivitaet;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Applikation;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Benutzer;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Berechtigungsklasse;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Datenverteiler;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Region;
import de.bsvrz.sys.funclib.bitctrl.modell.systemmodellglobal.objekte.Rolle;

/**
 * Fabrikmethode f&uuml;r gekapselte Systemobjekte aus dem Umfelddatenmodell.
 * Jedes gekapselte Objekt wird als Singleton behandelt und zwischengespeichert.
 *
 * @author BitCtrl Systems GmbH, Falko Schumann
 */
public class SystemModellGlobalObjektFactory implements ModellObjektFactory {

	@Override
	public SystemObjekt getModellobjekt(final SystemObject objekt) {
		if (objekt == null) {
			throw new IllegalArgumentException(
					"Argument darf nicht null sein.");
		}

		SystemObjekt obj = null;
		if (objekt.isOfType(SystemModellGlobalTypen.Aktivitaet.getPid())) {
			obj = new Aktivitaet(objekt);
		} else
			if (objekt.isOfType(SystemModellGlobalTypen.Applikation.getPid())) {
				obj = new Applikation(objekt);
			} else if (objekt.isOfType(SystemModellGlobalTypen.Benutzer.getPid())) {
				obj = new Benutzer(objekt);
			} else if (objekt.isOfType(
					SystemModellGlobalTypen.Berechtigungsklasse.getPid())) {
				obj = new Berechtigungsklasse(objekt);
			} else if (objekt
					.isOfType(SystemModellGlobalTypen.Datenverteiler.getPid())) {
				obj = new Datenverteiler(objekt);
			} else if (objekt.isOfType(SystemModellGlobalTypen.Region.getPid())) {
				obj = new Region(objekt);
			} else if (objekt.isOfType(SystemModellGlobalTypen.Rolle.getPid())) {
				obj = new Rolle(objekt);
			}

		return obj;
	}

	@Override
	public Collection<? extends SystemObjektTyp> getTypen() {
		return Arrays.asList(SystemModellGlobalTypen.values());
	}

}
